@@ -380,6 +380,33 @@ assert len(group1.variables.list()) == 0
 # g_l.delete()
 # assert len(group1.labels.list()) == 0
 
+
+# group import/export
+export = group1.exports.create()
+assert export.message == "202 Accepted"
+
+# We cannot check for export_status with group export API
+time.sleep(10)
+
+import_archive = "/tmp/gitlab-group-export.tgz"
+import_path = "imported_group"
+import_name = "Imported Group"
+
+with open(import_archive, "wb") as f:
+    export.download(streamed=True, action=f.write)
+
+with open(import_archive, "rb") as f:
+    output = gl.groups.import_group(f, import_path, import_name)
+assert output["message"] == "202 Accepted"
+
+# We cannot check for returned ID with group import API
+time.sleep(10)
+group_import = gl.groups.get(import_path)
+
+assert group_import.path == import_path
+assert group_import.name == import_name
+
+
 # hooks
 hook = gl.hooks.create({"url": "http://whatever.com"})
 assert len(gl.hooks.list()) == 1
@@ -473,6 +500,14 @@ commit = admin_project.commits.list()[0]
 # assert commit.refs()
 # assert commit.merge_requests()
 
+# commit GPG signature (for unsigned commits)
+# TODO: reasonable tests for signed commits?
+try:
+    signature = commit.signature()
+except gitlab.GitlabGetError as e:
+    error_message = e.error_message
+assert error_message == "404 GPG Signature Not Found"
+
 # commit comment
 commit.comments.create({"note": "This is a commit comment"})
 # assert len(commit.comments.list()) == 1
@@ -617,6 +652,56 @@ assert len(sudo_project.keys.list()) == 1
 sudo_project.keys.delete(deploy_key.id)
 assert len(sudo_project.keys.list()) == 0
 
+# deploy tokens
+deploy_token = admin_project.deploytokens.create(
+    {
+        "name": "foo",
+        "username": "bar",
+        "expires_at": "2022-01-01",
+        "scopes": ["read_registry"],
+    }
+)
+assert len(admin_project.deploytokens.list()) == 1
+assert gl.deploytokens.list() == admin_project.deploytokens.list()
+
+assert admin_project.deploytokens.list()[0].name == "foo"
+assert admin_project.deploytokens.list()[0].expires_at == "2022-01-01T00:00:00.000Z"
+assert admin_project.deploytokens.list()[0].scopes == ["read_registry"]
+# Uncomment once https://gitlab.com/gitlab-org/gitlab/-/issues/211963 is fixed
+# assert admin_project.deploytokens.list()[0].username == "bar"
+deploy_token.delete()
+assert len(admin_project.deploytokens.list()) == 0
+# Uncomment once https://gitlab.com/gitlab-org/gitlab/-/issues/212523 is fixed
+# assert len(gl.deploytokens.list()) == 0
+
+
+deploy_token_group = gl.groups.create(
+    {"name": "deploy_token_group", "path": "deploy_token_group"}
+)
+
+# Uncomment once https://gitlab.com/gitlab-org/gitlab/-/issues/211878 is fixed
+# deploy_token = group_deploy_token.deploytokens.create(
+#     {
+#         "name": "foo",
+#         "scopes": ["read_registry"],
+#     }
+# )
+
+# Remove once https://gitlab.com/gitlab-org/gitlab/-/issues/211878 is fixed
+deploy_token = deploy_token_group.deploytokens.create(
+    {"name": "foo", "username": "", "expires_at": "", "scopes": ["read_repository"],}
+)
+
+assert len(deploy_token_group.deploytokens.list()) == 1
+# Uncomment once https://gitlab.com/gitlab-org/gitlab/-/issues/212523 is fixed
+# assert gl.deploytokens.list() == deploy_token_group.deploytokens.list()
+deploy_token.delete()
+assert len(deploy_token_group.deploytokens.list()) == 0
+# Uncomment once https://gitlab.com/gitlab-org/gitlab/-/issues/212523 is fixed
+# assert len(gl.deploytokens.list()) == 0
+
+deploy_token_group.delete()
+
 # labels
 # label1 = admin_project.labels.create({"name": "label1", "color": "#778899"})
 # label1 = admin_project.labels.list()[0]
@@ -669,10 +754,17 @@ assert issue1.participants()
 assert type(issue1.closed_by()) == list
 assert type(issue1.related_merge_requests()) == list
 
-# issues labels and events
+# issue labels
 label2 = admin_project.labels.create({"name": "label2", "color": "#aabbcc"})
 issue1.labels = ["label2"]
 issue1.save()
+
+assert issue1 in admin_project.issues.list(labels=["label2"])
+assert issue1 in admin_project.issues.list(labels="label2")
+assert issue1 in admin_project.issues.list(labels="Any")
+assert issue1 not in admin_project.issues.list(labels="None")
+
+# issue events
 events = issue1.resourcelabelevents.list()
 assert events
 event = issue1.resourcelabelevents.get(events[0].id)
@@ -962,9 +1054,13 @@ with open("/tmp/gitlab-export.tgz", "wb") as f:
     ex.download(streamed=True, action=f.write)
 
 output = gl.projects.import_project(
-    open("/tmp/gitlab-export.tgz", "rb"), "imported_project"
+    open("/tmp/gitlab-export.tgz", "rb"), "imported_project", name="Imported Project"
 )
 project_import = gl.projects.get(output["id"], lazy=True).imports.get()
+
+assert project_import.path == "imported_project"
+assert project_import.name == "Imported Project"
+
 count = 0
 while project_import.import_status != "finished":
     time.sleep(1)
@@ -1001,6 +1097,23 @@ release_test_project.releases.delete(release_tag_name)
 assert len(release_test_project.releases.list()) == 0
 release_test_project.delete()
 
+# project remote mirrors
+mirror_url = "http://gitlab.test/root/mirror.git"
+
+# create remote mirror
+mirror = admin_project.remote_mirrors.create({"url": mirror_url})
+assert mirror.url == mirror_url
+
+# update remote mirror
+mirror.enabled = True
+mirror.save()
+
+# list remote mirrors
+mirror = admin_project.remote_mirrors.list()[0]
+assert isinstance(mirror, gitlab.v4.objects.ProjectRemoteMirror)
+assert mirror.url == mirror_url
+assert mirror.enabled is True
+
 # status
 message = "Test"
 emoji = "thumbsup"
